EmbyPy Videos
=====================

.. automodule:: embypy.objects
   :show-inheritance:

.. autosummary::
   Video.aspect_ratio
   Video.chapters

   Movie.premiere_date

   Episode.episode_number
   Episode.premiere_date
   Episode.season
   Episode.series

   Trailer

   AdultVideo

   MusicVideo

.. autoclass:: Video
   :members:

.. autoclass:: Movie
   :members:

.. autoclass:: Episode
   :members:

.. autoclass:: Trailer
   :members:

.. autoclass:: AdultVideo
   :members:

.. autoclass:: MusicVideo
   :members:
